"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    global_cluster_identifier: str = None,
    source_db_cluster_identifier: str = None,
    engine: str = None,
    engine_version: str = None,
    deletion_protection: bool = None,
    database_name: str = None,
    storage_encrypted: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Creates an Aurora global database spread across multiple Amazon Web Services Regions. The global database contains a single primary cluster with read-write capability, and a read-only secondary cluster that receives data from the primary cluster through high-speed replication performed by the Aurora storage subsystem.   You can create a global database that is initially empty, and then add a primary cluster and a secondary cluster to it. Or you can specify an existing Aurora cluster during the create operation, and this cluster becomes the primary cluster of the global database.   This action only applies to Aurora DB clusters.

    Args:
        global_cluster_identifier(str, optional): The cluster identifier of the new global database cluster. Defaults to None.
        source_db_cluster_identifier(str, optional):  The Amazon Resource Name (ARN) to use as the primary cluster of the global database. This parameter is optional. . Defaults to None.
        engine(str, optional): The name of the database engine to be used for this DB cluster. Defaults to None.
        engine_version(str, optional): The engine version of the Aurora global database. Defaults to None.
        deletion_protection(bool, optional):  The deletion protection setting for the new global database. The global database can't be deleted when deletion protection is enabled. . Defaults to None.
        database_name(str, optional):  The name for your database of up to 64 alpha-numeric characters. If you do not provide a name, Amazon Aurora will not create a database in the global database cluster you are creating. . Defaults to None.
        storage_encrypted(bool, optional):  The storage encryption setting for the new global database cluster. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.global_cluster.create(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.global_cluster.create
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="create_global_cluster",
        op_kwargs={
            "GlobalClusterIdentifier": global_cluster_identifier,
            "SourceDBClusterIdentifier": source_db_cluster_identifier,
            "Engine": engine,
            "EngineVersion": engine_version,
            "DeletionProtection": deletion_protection,
            "DatabaseName": database_name,
            "StorageEncrypted": storage_encrypted,
        },
    )


async def delete(hub, ctx, global_cluster_identifier: str) -> Dict:
    r"""
    **Autogenerated function**

     Deletes a global database cluster. The primary and secondary clusters must already be detached or destroyed first.   This action only applies to Aurora DB clusters.

    Args:
        global_cluster_identifier(str):  The cluster identifier of the global database cluster being deleted. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.global_cluster.delete(ctx, global_cluster_identifier=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.global_cluster.delete global_cluster_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="delete_global_cluster",
        op_kwargs={"GlobalClusterIdentifier": global_cluster_identifier},
    )


async def describe_all(
    hub,
    ctx,
    global_cluster_identifier: str = None,
    filters: List = None,
    max_records: int = None,
    marker: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Returns information about Aurora global database clusters. This API supports pagination.   For more information on Amazon Aurora, see  What Is Amazon Aurora? in the Amazon Aurora User Guide.   This action only applies to Aurora DB clusters.

    Args:
        global_cluster_identifier(str, optional):  The user-supplied DB cluster identifier. If this parameter is specified, information from only the specific DB cluster is returned. This parameter isn't case-sensitive.  Constraints:   If supplied, must match an existing DBClusterIdentifier.  . Defaults to None.
        filters(List, optional): This parameter isn't currently supported. Defaults to None.
        max_records(int, optional):  The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that you can retrieve the remaining results.  Default: 100 Constraints: Minimum 20, maximum 100. Defaults to None.
        marker(str, optional):  An optional pagination token provided by a previous DescribeGlobalClusters request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.global_cluster.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.global_cluster.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="describe_global_clusters",
        op_kwargs={
            "GlobalClusterIdentifier": global_cluster_identifier,
            "Filters": filters,
            "MaxRecords": max_records,
            "Marker": marker,
        },
    )


async def failover(
    hub, ctx, global_cluster_identifier: str, target_db_cluster_identifier: str
) -> Dict:
    r"""
    **Autogenerated function**

    Initiates the failover process for an Aurora global database (GlobalCluster). A failover for an Aurora global database promotes one of secondary read-only DB clusters to be the primary DB cluster and demotes the primary DB cluster to being a secondary (read-only) DB cluster. In other words, the role of the current primary DB cluster and the selected (target) DB cluster are switched. The selected secondary DB cluster assumes full read/write capabilities for the Aurora global database. For more information about failing over an Amazon Aurora global database, see Managed planned failover for Amazon Aurora global databases in the Amazon Aurora User Guide.   This action applies to GlobalCluster (Aurora global databases) only. Use this action only on healthy Aurora global databases with running Aurora DB clusters and no Region-wide outages, to test disaster recovery scenarios or to reconfigure your Aurora global database topology.

    Args:
        global_cluster_identifier(str): Identifier of the Aurora global database (GlobalCluster) that should be failed over. The identifier is the unique key assigned by the user when the Aurora global database was created. In other words, it's the name of the Aurora global database that you want to fail over.  Constraints:   Must match the identifier of an existing GlobalCluster (Aurora global database).  .
        target_db_cluster_identifier(str): Identifier of the secondary Aurora DB cluster that you want to promote to primary for the Aurora global database (GlobalCluster.) Use the Amazon Resource Name (ARN) for the identifier so that Aurora can locate the cluster in its Amazon Web Services Region. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.global_cluster.failover(
                ctx, global_cluster_identifier=value, target_db_cluster_identifier=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.global_cluster.failover global_cluster_identifier=value, target_db_cluster_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="failover_global_cluster",
        op_kwargs={
            "GlobalClusterIdentifier": global_cluster_identifier,
            "TargetDbClusterIdentifier": target_db_cluster_identifier,
        },
    )


async def modify(
    hub,
    ctx,
    global_cluster_identifier: str = None,
    new_global_cluster_identifier: str = None,
    deletion_protection: bool = None,
    engine_version: str = None,
    allow_major_version_upgrade: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Modify a setting for an Amazon Aurora global cluster. You can change one or more database configuration parameters by specifying these parameters and the new values in the request. For more information on Amazon Aurora, see  What Is Amazon Aurora? in the Amazon Aurora User Guide.   This action only applies to Aurora DB clusters.

    Args:
        global_cluster_identifier(str, optional):  The DB cluster identifier for the global cluster being modified. This parameter isn't case-sensitive.  Constraints:   Must match the identifier of an existing global database cluster.  . Defaults to None.
        new_global_cluster_identifier(str, optional):  The new cluster identifier for the global database cluster when modifying a global database cluster. This value is stored as a lowercase string.  Constraints:   Must contain from 1 to 63 letters, numbers, or hyphens   The first character must be a letter   Can't end with a hyphen or contain two consecutive hyphens   Example: my-cluster2 . Defaults to None.
        deletion_protection(bool, optional):  Indicates if the global database cluster has deletion protection enabled. The global database cluster can't be deleted when deletion protection is enabled. . Defaults to None.
        engine_version(str, optional): The version number of the database engine to which you want to upgrade. Changing this parameter results in an outage. The change is applied during the next maintenance window unless ApplyImmediately is enabled. To list all of the available engine versions for aurora (for MySQL 5.6-compatible Aurora), use the following command:  aws rds describe-db-engine-versions --engine aurora --query '*[]|[?SupportsGlobalDatabases == `true`].[EngineVersion]'  To list all of the available engine versions for aurora-mysql (for MySQL 5.7-compatible Aurora), use the following command:  aws rds describe-db-engine-versions --engine aurora-mysql --query '*[]|[?SupportsGlobalDatabases == `true`].[EngineVersion]'  To list all of the available engine versions for aurora-postgresql, use the following command:  aws rds describe-db-engine-versions --engine aurora-postgresql --query '*[]|[?SupportsGlobalDatabases == `true`].[EngineVersion]' . Defaults to None.
        allow_major_version_upgrade(bool, optional): A value that indicates whether major version upgrades are allowed. Constraints: You must allow major version upgrades when specifying a value for the EngineVersion parameter that is a different major version than the DB cluster's current version. If you upgrade the major version of a global database, the cluster and DB instance parameter groups are set to the default parameter groups for the new version. Apply any custom parameter groups after completing the upgrade. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.global_cluster.modify(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.global_cluster.modify
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="modify_global_cluster",
        op_kwargs={
            "GlobalClusterIdentifier": global_cluster_identifier,
            "NewGlobalClusterIdentifier": new_global_cluster_identifier,
            "DeletionProtection": deletion_protection,
            "EngineVersion": engine_version,
            "AllowMajorVersionUpgrade": allow_major_version_upgrade,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__func_alias__ = {"set_": "set"}


async def set_(hub, ctx, load_balancer_arn: str, security_groups: List) -> Dict:
    r"""
    **Autogenerated function**

    Associates the specified security groups with the specified Application Load Balancer. The specified security groups override the previously associated security groups. You can't specify a security group for a Network Load Balancer or Gateway Load Balancer.

    Args:
        load_balancer_arn(str): The Amazon Resource Name (ARN) of the load balancer.
        security_groups(List): The IDs of the security groups.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elbv2.security_group.set(
                ctx, load_balancer_arn=value, security_groups=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elbv2.security_group.set load_balancer_arn=value, security_groups=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elbv2",
        operation="set_security_groups",
        op_kwargs={
            "LoadBalancerArn": load_balancer_arn,
            "SecurityGroups": security_groups,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__func_alias__ = {"list_": "list"}


async def list_(hub, ctx, resource_name: str, filters: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists all tags on an Amazon Neptune resource.

    Args:
        resource_name(str): The Amazon Neptune resource with tags to be listed. This value is an Amazon Resource Name (ARN). For information about creating an ARN, see  Constructing an Amazon Resource Name (ARN).
        filters(List, optional): This parameter is not currently supported. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.neptune.tags.for_resource.list(ctx, resource_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.neptune.tags.for_resource.list resource_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="neptune",
        operation="list_tags_for_resource",
        op_kwargs={"ResourceName": resource_name, "Filters": filters},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get_all(
    hub,
    ctx,
    time_period: Dict,
    dimension: str,
    search_string: str = None,
    context: str = None,
    filter_: Dict = None,
    sort_by: List = None,
    max_results: int = None,
    next_page_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves all available filter values for a specified filter over a period of time. You can search the dimension values for an arbitrary string.

    Args:
        search_string(str, optional): The value that you want to search the filter values for. Defaults to None.
        time_period(Dict): The start and end dates for retrieving the dimension values. The start date is inclusive, but the end date is exclusive. For example, if start is 2017-01-01 and end is 2017-05-01, then the cost and usage data is retrieved from 2017-01-01 up to and including 2017-04-30 but not including 2017-05-01.
        dimension(str): The name of the dimension. Each Dimension is available for a different Context. For more information, see Context. .
        context(str, optional): The context for the call to GetDimensionValues. This can be RESERVATIONS or COST_AND_USAGE. The default value is COST_AND_USAGE. If the context is set to RESERVATIONS, the resulting dimension values can be used in the GetReservationUtilization operation. If the context is set to COST_AND_USAGE, the resulting dimension values can be used in the GetCostAndUsage operation. If you set the context to COST_AND_USAGE, you can use the following dimensions for searching:   AZ - The Availability Zone. An example is us-east-1a.   DATABASE_ENGINE - The Amazon Relational Database Service database. Examples are Aurora or MySQL.   INSTANCE_TYPE - The type of Amazon EC2 instance. An example is m4.xlarge.   LEGAL_ENTITY_NAME - The name of the organization that sells you AWS services, such as Amazon Web Services.   LINKED_ACCOUNT - The description in the attribute map that includes the full name of the member account. The value field contains the AWS ID of the member account.   OPERATING_SYSTEM - The operating system. Examples are Windows or Linux.   OPERATION - The action performed. Examples include RunInstance and CreateBucket.   PLATFORM - The Amazon EC2 operating system. Examples are Windows or Linux.   PURCHASE_TYPE - The reservation type of the purchase to which this usage is related. Examples include On-Demand Instances and Standard Reserved Instances.   SERVICE - The AWS service such as Amazon DynamoDB.   USAGE_TYPE - The type of usage. An example is DataTransfer-In-Bytes. The response for the GetDimensionValues operation includes a unit attribute. Examples include GB and Hrs.   USAGE_TYPE_GROUP - The grouping of common usage types. An example is Amazon EC2: CloudWatch – Alarms. The response for this operation includes a unit attribute.   REGION - The AWS Region.   RECORD_TYPE - The different types of charges such as RI fees, usage costs, tax refunds, and credits.   RESOURCE_ID - The unique identifier of the resource. ResourceId is an opt-in feature only available for last 14 days for EC2-Compute Service.   If you set the context to RESERVATIONS, you can use the following dimensions for searching:   AZ - The Availability Zone. An example is us-east-1a.   CACHE_ENGINE - The Amazon ElastiCache operating system. Examples are Windows or Linux.   DEPLOYMENT_OPTION - The scope of Amazon Relational Database Service deployments. Valid values are SingleAZ and MultiAZ.   INSTANCE_TYPE - The type of Amazon EC2 instance. An example is m4.xlarge.   LINKED_ACCOUNT - The description in the attribute map that includes the full name of the member account. The value field contains the AWS ID of the member account.   PLATFORM - The Amazon EC2 operating system. Examples are Windows or Linux.   REGION - The AWS Region.   SCOPE (Utilization only) - The scope of a Reserved Instance (RI). Values are regional or a single Availability Zone.   TAG (Coverage only) - The tags that are associated with a Reserved Instance (RI).   TENANCY - The tenancy of a resource. Examples are shared or dedicated.   If you set the context to SAVINGS_PLANS, you can use the following dimensions for searching:   SAVINGS_PLANS_TYPE - Type of Savings Plans (EC2 Instance or Compute)   PAYMENT_OPTION - Payment option for the given Savings Plans (for example, All Upfront)   REGION - The AWS Region.   INSTANCE_TYPE_FAMILY - The family of instances (For example, m5)   LINKED_ACCOUNT - The description in the attribute map that includes the full name of the member account. The value field contains the AWS ID of the member account.   SAVINGS_PLAN_ARN - The unique identifier for your Savings Plan  . Defaults to None.
        filter_(Dict, optional): Use Expression to filter by cost or by usage. There are two patterns:    Simple dimension values - You can set the dimension name and values for the filters that you plan to use. For example, you can filter for REGION==us-east-1 OR REGION==us-west-1. For GetRightsizingRecommendation, the Region is a full name (for example, REGION==US East (N. Virginia). The Expression example looks like:  { "Dimensions": { "Key": "REGION", "Values": [ "us-east-1", “us-west-1” ] } }  The list of dimension values are OR'd together to retrieve cost or usage data. You can create Expression and DimensionValues objects using either with* methods or set* methods in multiple lines.    Compound dimension values with logical operations - You can use multiple Expression types and the logical operators AND/OR/NOT to create a list of one or more Expression objects. This allows you to filter on more advanced options. For example, you can filter on ((REGION == us-east-1 OR REGION == us-west-1) OR (TAG.Type == Type1)) AND (USAGE_TYPE != DataTransfer). The Expression for that looks like this:  { "And": [ {"Or": [ {"Dimensions": { "Key": "REGION", "Values": [ "us-east-1", "us-west-1" ] }}, {"Tags": { "Key": "TagName", "Values": ["Value1"] } } ]}, {"Not": {"Dimensions": { "Key": "USAGE_TYPE", "Values": ["DataTransfer"] }}} ] }    Because each Expression can have only one operator, the service returns an error if more than one is specified. The following example shows an Expression object that creates an error.    { "And": [ ... ], "DimensionValues": { "Dimension": "USAGE_TYPE", "Values": [ "DataTransfer" ] } }      For the GetRightsizingRecommendation action, a combination of OR and NOT is not supported. OR is not supported between different dimensions, or dimensions and tags. NOT operators aren't supported. Dimensions are also limited to LINKED_ACCOUNT, REGION, or RIGHTSIZING_TYPE. For the GetReservationPurchaseRecommendation action, only NOT is supported. AND and OR are not supported. Dimensions are limited to LINKED_ACCOUNT. . Defaults to None.
        sort_by(List, optional): The value by which you want to sort the data. The key represents cost and usage metrics. The following values are supported:    BlendedCost     UnblendedCost     AmortizedCost     NetAmortizedCost     NetUnblendedCost     UsageQuantity     NormalizedUsageAmount    Supported values for SortOrder are ASCENDING or DESCENDING. When you specify a SortBy paramater, the context must be COST_AND_USAGE. Further, when using SortBy, NextPageToken and SearchString are not supported. Defaults to None.
        max_results(int, optional): This field is only used when SortBy is provided in the request. The maximum number of objects that to be returned for this request. If MaxResults is not specified with SortBy, the request will return 1000 results as the default value for this parameter. For GetDimensionValues, MaxResults has an upper limit of 1000. Defaults to None.
        next_page_token(str, optional): The token to retrieve the next set of results. AWS provides the token when the response from a previous call has more results than the maximum page size. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ce.dimension_value.get_all(
                ctx, time_period=value, dimension=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ce.dimension_value.get_all time_period=value, dimension=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ce",
        operation="get_dimension_values",
        op_kwargs={
            "SearchString": search_string,
            "TimePeriod": time_period,
            "Dimension": dimension,
            "Context": context,
            "Filter": filter_,
            "SortBy": sort_by,
            "MaxResults": max_results,
            "NextPageToken": next_page_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    app_instance_arn: str,
    name: str,
    client_request_token: str,
    mode: str = None,
    privacy: str = None,
    metadata: str = None,
    tags: List = None,
    chime_bearer: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a channel to which you can add users and send messages.  Restriction: You can't change a channel's privacy.  The x-amz-chime-bearer request header is mandatory. Use the AppInstanceUserArn of the user that makes the API call as the value in the header.

    Args:
        app_instance_arn(str): The ARN of the channel request.
        name(str): The name of the channel.
        mode(str, optional): The channel mode: UNRESTRICTED or RESTRICTED. Administrators, moderators, and channel members can add themselves and other members to unrestricted channels. Only administrators and moderators can add members to restricted channels. Defaults to None.
        privacy(str, optional): The channel's privacy level: PUBLIC or PRIVATE. Private channels aren't discoverable by users outside the channel. Public channels are discoverable by anyone in the AppInstance. Defaults to None.
        metadata(str, optional): The metadata of the creation request. Limited to 1KB and UTF-8. Defaults to None.
        client_request_token(str): The client token for the request. An Idempotency token.
        tags(List, optional): The tags for the creation request. Defaults to None.
        chime_bearer(str, optional): The AppInstanceUserArn of the user that makes the API call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.channel.init.create(
                ctx, app_instance_arn=value, name=value, client_request_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.channel.init.create app_instance_arn=value, name=value, client_request_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="create_channel",
        op_kwargs={
            "AppInstanceArn": app_instance_arn,
            "Name": name,
            "Mode": mode,
            "Privacy": privacy,
            "Metadata": metadata,
            "ClientRequestToken": client_request_token,
            "Tags": tags,
            "ChimeBearer": chime_bearer,
        },
    )


async def delete(hub, ctx, channel_arn: str, chime_bearer: str = None) -> None:
    r"""
    **Autogenerated function**

    Immediately makes a channel and its memberships inaccessible and marks them for deletion. This is an irreversible process.  The x-amz-chime-bearer request header is mandatory. Use the AppInstanceUserArn of the user that makes the API call as the value in the header.

    Args:
        channel_arn(str): The ARN of the channel being deleted.
        chime_bearer(str, optional): The AppInstanceUserArn of the user that makes the API call. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.channel.init.delete(ctx, channel_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.channel.init.delete channel_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="delete_channel",
        op_kwargs={"ChannelArn": channel_arn, "ChimeBearer": chime_bearer},
    )


async def describe(hub, ctx, channel_arn: str, chime_bearer: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns the full details of a channel in an Amazon Chime AppInstance.  The x-amz-chime-bearer request header is mandatory. Use the AppInstanceUserArn of the user that makes the API call as the value in the header.

    Args:
        channel_arn(str): The ARN of the channel.
        chime_bearer(str, optional): The AppInstanceUserArn of the user that makes the API call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.channel.init.describe(ctx, channel_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.channel.init.describe channel_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="describe_channel",
        op_kwargs={"ChannelArn": channel_arn, "ChimeBearer": chime_bearer},
    )


async def list_all(
    hub,
    ctx,
    app_instance_arn: str,
    privacy: str = None,
    max_results: int = None,
    next_token: str = None,
    chime_bearer: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all Channels created under a single Chime App as a paginated list. You can specify filters to narrow results.  Functionality & restrictions    Use privacy = PUBLIC to retrieve all public channels in the account.   Only an AppInstanceAdmin can set privacy = PRIVATE to list the private channels in an account.    The x-amz-chime-bearer request header is mandatory. Use the AppInstanceUserArn of the user that makes the API call as the value in the header.

    Args:
        app_instance_arn(str): The ARN of the AppInstance.
        privacy(str, optional): The privacy setting. PUBLIC retrieves all the public channels. PRIVATE retrieves private channels. Only an AppInstanceAdmin can retrieve private channels. . Defaults to None.
        max_results(int, optional): The maximum number of channels that you want to return. Defaults to None.
        next_token(str, optional): The token passed by previous API calls until all requested channels are returned. Defaults to None.
        chime_bearer(str, optional): The AppInstanceUserArn of the user that makes the API call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.channel.init.list_all(ctx, app_instance_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.channel.init.list_all app_instance_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="list_channels",
        op_kwargs={
            "AppInstanceArn": app_instance_arn,
            "Privacy": privacy,
            "MaxResults": max_results,
            "NextToken": next_token,
            "ChimeBearer": chime_bearer,
        },
    )


async def update(
    hub,
    ctx,
    channel_arn: str,
    name: str,
    mode: str,
    metadata: str = None,
    chime_bearer: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Update a channel's attributes.  Restriction: You can't change a channel's privacy.   The x-amz-chime-bearer request header is mandatory. Use the AppInstanceUserArn of the user that makes the API call as the value in the header.

    Args:
        channel_arn(str): The ARN of the channel.
        name(str): The name of the channel.
        mode(str): The mode of the update request.
        metadata(str, optional): The metadata for the update request. Defaults to None.
        chime_bearer(str, optional): The AppInstanceUserArn of the user that makes the API call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.channel.init.update(
                ctx, channel_arn=value, name=value, mode=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.channel.init.update channel_arn=value, name=value, mode=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="update_channel",
        op_kwargs={
            "ChannelArn": channel_arn,
            "Name": name,
            "Mode": mode,
            "Metadata": metadata,
            "ChimeBearer": chime_bearer,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import List


async def create_multiple(hub, ctx, tags: List) -> None:
    r"""
    **Autogenerated function**

    Creates or updates tags for the specified Auto Scaling group. When you specify a tag with a key that already exists, the operation overwrites the previous tag definition, and you do not get an error message. For more information, see Tagging Auto Scaling groups and instances in the Amazon EC2 Auto Scaling User Guide.

    Args:
        tags(List): One or more tags.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.autoscaling.or_update_tag.create_multiple(ctx, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.autoscaling.or_update_tag.create_multiple tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="autoscaling",
        operation="create_or_update_tags",
        op_kwargs={"Tags": tags},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub, ctx, access_token: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all AWS accounts assigned to the user. These AWS accounts are assigned by the administrator of the account. For more information, see Assign User Access in the AWS SSO User Guide. This operation returns a paginated response.

    Args:
        next_token(str, optional): (Optional) When requesting subsequent pages, this is the page token from the previous response output. Defaults to None.
        max_results(int, optional): This is the number of items clients can request per page. Defaults to None.
        access_token(str): The token issued by the CreateToken API call. For more information, see CreateToken in the AWS SSO OIDC API Reference Guide.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sso.account.init.list_all(ctx, access_token=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sso.account.init.list_all access_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sso",
        operation="list_accounts",
        op_kwargs={
            "nextToken": next_token,
            "maxResults": max_results,
            "accessToken": access_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(hub, ctx, instance_id: str, initial_contact_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the contact attributes for the specified contact.

    Args:
        instance_id(str): The identifier of the Amazon Connect instance.
        initial_contact_id(str): The identifier of the initial contact.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.contact.attribute.get_all(
                ctx, instance_id=value, initial_contact_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.contact.attribute.get_all instance_id=value, initial_contact_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="get_contact_attributes",
        op_kwargs={"InstanceId": instance_id, "InitialContactId": initial_contact_id},
    )


async def update_multiple(
    hub, ctx, initial_contact_id: str, instance_id: str, attributes: Dict
) -> Dict:
    r"""
    **Autogenerated function**

    Creates or updates user-defined contact attributes associated with the specified contact. You can create or update user-defined attributes for both ongoing and completed contacts. For example, while the call is active, you can update the customer's name or the reason the customer called. You can add notes about steps that the agent took during the call that display to the next agent that takes the call. You can also update attributes for a contact using data from your CRM application and save the data with the contact in Amazon Connect. You could also flag calls for additional analysis, such as legal review or to identify abusive callers. Contact attributes are available in Amazon Connect for 24 months, and are then deleted. For information about CTR retention and the maximum size of the CTR attributes section, see Feature specifications in the Amazon Connect Administrator Guide.   Important: You cannot use the operation to update attributes for contacts that occurred prior to the release of the API, which was September 12, 2018. You can update attributes only for contacts that started after the release of the API. If you attempt to update attributes for a contact that occurred prior to the release of the API, a 400 error is returned. This applies also to queued callbacks that were initiated prior to the release of the API but are still active in your instance.

    Args:
        initial_contact_id(str): The identifier of the contact. This is the identifier of the contact associated with the first interaction with the contact center.
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.
        attributes(Dict): The Amazon Connect attributes. These attributes can be accessed in contact flows just like any other contact attributes. You can have up to 32,768 UTF-8 bytes across all attributes for a contact. Attribute keys can include only alphanumeric, dash, and underscore characters.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.contact.attribute.update_multiple(
                ctx, initial_contact_id=value, instance_id=value, attributes=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.contact.attribute.update_multiple initial_contact_id=value, instance_id=value, attributes=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="update_contact_attributes",
        op_kwargs={
            "InitialContactId": initial_contact_id,
            "InstanceId": instance_id,
            "Attributes": attributes,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def disable(hub, ctx, image_id: str, dry_run: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Cancels the deprecation of the specified AMI. For more information, see Deprecate an AMI in the Amazon Elastic Compute Cloud User Guide.

    Args:
        image_id(str): The ID of the AMI.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.image.deprecation.disable(ctx, image_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.image.deprecation.disable image_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="disable_image_deprecation",
        op_kwargs={"ImageId": image_id, "DryRun": dry_run},
    )


async def enable(
    hub, ctx, image_id: str, deprecate_at: str, dry_run: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Enables deprecation of the specified AMI at the specified date and time. For more information, see Deprecate an AMI in the Amazon Elastic Compute Cloud User Guide.

    Args:
        image_id(str): The ID of the AMI.
        deprecate_at(str): The date and time to deprecate the AMI, in UTC, in the following format: YYYY-MM-DDTHH:MM:SSZ. If you specify a value for seconds, Amazon EC2 rounds the seconds to the nearest minute. You can’t specify a date in the past. The upper limit for DeprecateAt is 10 years from now.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.image.deprecation.enable(
                ctx, image_id=value, deprecate_at=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.image.deprecation.enable image_id=value, deprecate_at=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="enable_image_deprecation",
        op_kwargs={"ImageId": image_id, "DeprecateAt": deprecate_at, "DryRun": dry_run},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    datastore_name: str,
    datastore_storage: Dict = None,
    retention_period: Dict = None,
    tags: List = None,
    file_format_configuration: Dict = None,
    datastore_partitions: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a data store, which is a repository for messages.

    Args:
        datastore_name(str): The name of the data store.
        datastore_storage(Dict, optional): Where data in a data store is stored.. You can choose serviceManagedS3 storage, customerManagedS3 storage, or iotSiteWiseMultiLayerStorage storage. The default is serviceManagedS3. You can't change the choice of Amazon S3 storage after your data store is created. . Defaults to None.
        retention_period(Dict, optional): How long, in days, message data is kept for the data store. When customerManagedS3 storage is selected, this parameter is ignored. Defaults to None.
        tags(List, optional): Metadata which can be used to manage the data store. Defaults to None.
        file_format_configuration(Dict, optional): Contains the configuration information of file formats. IoT Analytics data stores support JSON and Parquet. The default file format is JSON. You can specify only one format. You can't change the file format after you create the data store. Defaults to None.
        datastore_partitions(Dict, optional):  Contains information about the partition dimensions in a data store. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotanalytic.datastore.create(ctx, datastore_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotanalytic.datastore.create datastore_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotanalytics",
        operation="create_datastore",
        op_kwargs={
            "datastoreName": datastore_name,
            "datastoreStorage": datastore_storage,
            "retentionPeriod": retention_period,
            "tags": tags,
            "fileFormatConfiguration": file_format_configuration,
            "datastorePartitions": datastore_partitions,
        },
    )


async def delete(hub, ctx, datastore_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified data store.

    Args:
        datastore_name(str): The name of the data store to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotanalytic.datastore.delete(ctx, datastore_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotanalytic.datastore.delete datastore_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotanalytics",
        operation="delete_datastore",
        op_kwargs={"datastoreName": datastore_name},
    )


async def describe(
    hub, ctx, datastore_name: str, include_statistics: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about a data store.

    Args:
        datastore_name(str): The name of the data store.
        include_statistics(bool, optional): If true, additional statistical information about the data store is included in the response. This feature can't be used with a data store whose S3 storage is customer-managed. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotanalytic.datastore.describe(ctx, datastore_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotanalytic.datastore.describe datastore_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotanalytics",
        operation="describe_datastore",
        op_kwargs={
            "datastoreName": datastore_name,
            "includeStatistics": include_statistics,
        },
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a list of data stores.

    Args:
        next_token(str, optional): The token for the next set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return in this request. The default value is 100. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotanalytic.datastore.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotanalytic.datastore.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotanalytics",
        operation="list_datastores",
        op_kwargs={"nextToken": next_token, "maxResults": max_results},
    )


async def update(
    hub,
    ctx,
    datastore_name: str,
    retention_period: Dict = None,
    datastore_storage: Dict = None,
    file_format_configuration: Dict = None,
) -> None:
    r"""
    **Autogenerated function**

    Used to update the settings of a data store.

    Args:
        datastore_name(str): The name of the data store to be updated.
        retention_period(Dict, optional): How long, in days, message data is kept for the data store. The retention period can't be updated if the data store's Amazon S3 storage is customer-managed. Defaults to None.
        datastore_storage(Dict, optional): Where data in a data store is stored.. You can choose serviceManagedS3 storage, customerManagedS3 storage, or iotSiteWiseMultiLayerStorage storage. The default is serviceManagedS3. You can't change the choice of Amazon S3 storage after your data store is created. . Defaults to None.
        file_format_configuration(Dict, optional): Contains the configuration information of file formats. IoT Analytics data stores support JSON and Parquet. The default file format is JSON. You can specify only one format. You can't change the file format after you create the data store. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotanalytic.datastore.update(ctx, datastore_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotanalytic.datastore.update datastore_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotanalytics",
        operation="update_datastore",
        op_kwargs={
            "datastoreName": datastore_name,
            "retentionPeriod": retention_period,
            "datastoreStorage": datastore_storage,
            "fileFormatConfiguration": file_format_configuration,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def report(hub, ctx, task_id: str, fields: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Task runners call ReportTaskProgress when assigned a task to acknowledge that it has the task. If the web service does not receive this acknowledgement within 2 minutes, it assigns the task in a subsequent PollForTask call. After this initial acknowledgement, the task runner only needs to report progress every 15 minutes to maintain its ownership of the task. You can change this reporting time from 15 minutes by specifying a reportProgressTimeout field in your pipeline. If a task runner does not report its status after 5 minutes, AWS Data Pipeline assumes that the task runner is unable to process the task and reassigns the task in a subsequent response to PollForTask. Task runners should call ReportTaskProgress every 60 seconds.

    Args:
        task_id(str): The ID of the task assigned to the task runner. This value is provided in the response for PollForTask.
        fields(List, optional): Key-value pairs that define the properties of the ReportTaskProgressInput object. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.datapipeline.task.progress.report(ctx, task_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.datapipeline.task.progress.report task_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="datapipeline",
        operation="report_task_progress",
        op_kwargs={"taskId": task_id, "fields": fields},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__func_alias__ = {"set_": "set"}


async def set_(hub, ctx, rule_priorities: List) -> Dict:
    r"""
    **Autogenerated function**

    Sets the priorities of the specified rules. You can reorder the rules as long as there are no priority conflicts in the new order. Any existing rules that you do not specify retain their current priority.

    Args:
        rule_priorities(List): The rule priorities.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elbv2.rule.priority.set(ctx, rule_priorities=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elbv2.rule.priority.set rule_priorities=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elbv2",
        operation="set_rule_priorities",
        op_kwargs={"RulePriorities": rule_priorities},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def accept(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    In a management account, an environment account connection request is accepted. When the environment account connection request is accepted, AWS Proton can use the associated IAM role to provision environment infrastructure resources in the associated environment account. For more information, see Environment account connections in the AWS Proton Administrator guide.

    Args:
        id_(str): The ID of the environment account connection.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.proton.environment.account_connection.accept(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.proton.environment.account_connection.accept id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="proton",
        operation="accept_environment_account_connection",
        op_kwargs={"id": id_},
    )


async def create(
    hub,
    ctx,
    environment_name: str,
    management_account_id: str,
    role_arn: str,
    client_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Create an environment account connection in an environment account so that environment infrastructure resources can be provisioned in the environment account from a management account. An environment account connection is a secure bi-directional connection between a management account and an environment account that maintains authorization and permissions. For more information, see Environment account connections in the AWS Proton Administrator guide.

    Args:
        client_token(str, optional): When included, if two identicial requests are made with the same client token, AWS Proton returns the environment account connection that the first request created. Defaults to None.
        environment_name(str): The name of the AWS Proton environment that's created in the associated management account.
        management_account_id(str): The ID of the management account that accepts or rejects the environment account connection. You create an manage the AWS Proton environment in this account. If the management account accepts the environment account connection, AWS Proton can use the associated IAM role to provision environment infrastructure resources in the associated environment account.
        role_arn(str): The Amazon Resource Name (ARN) of the IAM service role that's created in the environment account. AWS Proton uses this role to provision infrastructure resources in the associated environment account.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.proton.environment.account_connection.create(
                ctx, environment_name=value, management_account_id=value, role_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.proton.environment.account_connection.create environment_name=value, management_account_id=value, role_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="proton",
        operation="create_environment_account_connection",
        op_kwargs={
            "clientToken": client_token,
            "environmentName": environment_name,
            "managementAccountId": management_account_id,
            "roleArn": role_arn,
        },
    )


async def delete(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    In an environment account, delete an environment account connection. After you delete an environment account connection that’s in use by an AWS Proton environment, AWS Proton can’t manage the environment infrastructure resources until a new environment account connection is accepted for the environment account and associated environment. You're responsible for cleaning up provisioned resources that remain without an environment connection. For more information, see Environment account connections in the AWS Proton Administrator guide.

    Args:
        id_(str): The ID of the environment account connection to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.proton.environment.account_connection.delete(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.proton.environment.account_connection.delete id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="proton",
        operation="delete_environment_account_connection",
        op_kwargs={"id": id_},
    )


async def get(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    In an environment account, view the detail data for an environment account connection. For more information, see Environment account connections in the AWS Proton Administrator guide.

    Args:
        id_(str): The ID of the environment account connection.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.proton.environment.account_connection.get(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.proton.environment.account_connection.get id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="proton",
        operation="get_environment_account_connection",
        op_kwargs={"id": id_},
    )


async def list_all(
    hub,
    ctx,
    requested_by: str,
    environment_name: str = None,
    max_results: int = None,
    next_token: str = None,
    statuses: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    View a list of environment account connections. For more information, see Environment account connections in the AWS Proton Administrator guide.

    Args:
        environment_name(str, optional): The environment name that's associated with each listed environment account connection. Defaults to None.
        max_results(int, optional): The maximum number of environment account connections to list. Defaults to None.
        next_token(str, optional): A token to indicate the location of the next environment account connection in the array of environment account connections, after the list of environment account connections that was previously requested. Defaults to None.
        requested_by(str): The type of account making the ListEnvironmentAccountConnections request.
        statuses(List, optional): The status details for each listed environment account connection. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.proton.environment.account_connection.list_all(
                ctx, requested_by=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.proton.environment.account_connection.list_all requested_by=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="proton",
        operation="list_environment_account_connections",
        op_kwargs={
            "environmentName": environment_name,
            "maxResults": max_results,
            "nextToken": next_token,
            "requestedBy": requested_by,
            "statuses": statuses,
        },
    )


async def reject(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    In a management account, reject an environment account connection from another environment account. After you reject an environment account connection request, you won’t be able to accept or use the rejected environment account connection. You can’t reject an environment account connection that is connected to an environment. For more information, see Environment account connections in the AWS Proton Administrator guide.

    Args:
        id_(str): The ID of the environment account connection to reject.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.proton.environment.account_connection.reject(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.proton.environment.account_connection.reject id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="proton",
        operation="reject_environment_account_connection",
        op_kwargs={"id": id_},
    )


async def update(hub, ctx, id_: str, role_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    In an environment account, update an environment account connection to use a new IAM role. For more information, see Environment account connections in the AWS Proton Administrator guide.

    Args:
        id_(str): The ID of the environment account connection to update.
        role_arn(str): The Amazon Resource Name (ARN) of the IAM service role that is associated with the environment account connection to update.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.proton.environment.account_connection.update(
                ctx, id_=value, role_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.proton.environment.account_connection.update id_=value, role_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="proton",
        operation="update_environment_account_connection",
        op_kwargs={"id": id_, "roleArn": role_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    instance_id: str,
    snapshot_id: str = None,
    client_token: str = None,
    dry_run: bool = None,
    tag_specifications: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a root volume replacement task for an Amazon EC2 instance. The root volume can either be restored to its initial launch state, or it can be restored using a specific snapshot. For more information, see Replace a root volume in the Amazon Elastic Compute Cloud User Guide.

    Args:
        instance_id(str): The ID of the instance for which to replace the root volume.
        snapshot_id(str, optional): The ID of the snapshot from which to restore the replacement root volume. If you want to restore the volume to the initial launch state, omit this parameter. Defaults to None.
        client_token(str, optional): Unique, case-sensitive identifier you provide to ensure the idempotency of the request. If you do not specify a client token, a randomly generated token is used for the request to ensure idempotency. For more information, see Ensuring idempotency. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        tag_specifications(List, optional): The tags to apply to the root volume replacement task. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.replace_root_volume_task.create(ctx, instance_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.replace_root_volume_task.create instance_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="create_replace_root_volume_task",
        op_kwargs={
            "InstanceId": instance_id,
            "SnapshotId": snapshot_id,
            "ClientToken": client_token,
            "DryRun": dry_run,
            "TagSpecifications": tag_specifications,
        },
    )


async def describe_all(
    hub,
    ctx,
    replace_root_volume_task_ids: List = None,
    filters: List = None,
    max_results: int = None,
    next_token: str = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes a root volume replacement task. For more information, see Replace a root volume in the Amazon Elastic Compute Cloud User Guide.

    Args:
        replace_root_volume_task_ids(List, optional): The ID of the root volume replacement task to view. Defaults to None.
        filters(List, optional): Filter to use:    instance-id - The ID of the instance for which the root volume replacement task was created.  . Defaults to None.
        max_results(int, optional): The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value. Defaults to None.
        next_token(str, optional): The token for the next page of results. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.replace_root_volume_task.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.replace_root_volume_task.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_replace_root_volume_tasks",
        op_kwargs={
            "ReplaceRootVolumeTaskIds": replace_root_volume_task_ids,
            "Filters": filters,
            "MaxResults": max_results,
            "NextToken": next_token,
            "DryRun": dry_run,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def disassociate(
    hub, ctx, project_name: str, placement_name: str, device_template_name: str
) -> Dict:
    r"""
    **Autogenerated function**

    Removes a physical device from a placement.

    Args:
        project_name(str): The name of the project that contains the placement.
        placement_name(str): The name of the placement that the device should be removed from.
        device_template_name(str): The device ID that should be removed from the placement.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot1click_project.device.from_placement.disassociate(
                ctx, project_name=value, placement_name=value, device_template_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot1click_project.device.from_placement.disassociate project_name=value, placement_name=value, device_template_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot1click-projects",
        operation="disassociate_device_from_placement",
        op_kwargs={
            "projectName": project_name,
            "placementName": placement_name,
            "deviceTemplateName": device_template_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    contact_list_name: str,
    email_address: str,
    topic_preferences: List = None,
    unsubscribe_all: bool = None,
    attributes_data: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a contact, which is an end-user who is receiving the email, and adds them to a contact list.

    Args:
        contact_list_name(str): The name of the contact list to which the contact should be added.
        email_address(str): The contact's email address.
        topic_preferences(List, optional): The contact's preferences for being opted-in to or opted-out of topics. Defaults to None.
        unsubscribe_all(bool, optional): A boolean value status noting if the contact is unsubscribed from all contact list topics. Defaults to None.
        attributes_data(str, optional): The attribute data attached to a contact. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sesv2.contact.init.create(
                ctx, contact_list_name=value, email_address=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sesv2.contact.init.create contact_list_name=value, email_address=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sesv2",
        operation="create_contact",
        op_kwargs={
            "ContactListName": contact_list_name,
            "EmailAddress": email_address,
            "TopicPreferences": topic_preferences,
            "UnsubscribeAll": unsubscribe_all,
            "AttributesData": attributes_data,
        },
    )


async def delete(hub, ctx, contact_list_name: str, email_address: str) -> Dict:
    r"""
    **Autogenerated function**

    Removes a contact from a contact list.

    Args:
        contact_list_name(str): The name of the contact list from which the contact should be removed.
        email_address(str): The contact's email address.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sesv2.contact.init.delete(
                ctx, contact_list_name=value, email_address=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sesv2.contact.init.delete contact_list_name=value, email_address=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sesv2",
        operation="delete_contact",
        op_kwargs={"ContactListName": contact_list_name, "EmailAddress": email_address},
    )


async def get(hub, ctx, contact_list_name: str, email_address: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns a contact from a contact list.

    Args:
        contact_list_name(str): The name of the contact list to which the contact belongs.
        email_address(str): The contact's email addres.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sesv2.contact.init.get(
                ctx, contact_list_name=value, email_address=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sesv2.contact.init.get contact_list_name=value, email_address=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sesv2",
        operation="get_contact",
        op_kwargs={"ContactListName": contact_list_name, "EmailAddress": email_address},
    )


async def list_all(
    hub,
    ctx,
    contact_list_name: str,
    filter_: Dict = None,
    page_size: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the contacts present in a specific contact list.

    Args:
        contact_list_name(str): The name of the contact list.
        filter_(Dict, optional): A filter that can be applied to a list of contacts. Defaults to None.
        page_size(int, optional): The number of contacts that may be returned at once, which is dependent on if there are more or less contacts than the value of the PageSize. Use this parameter to paginate results. If additional contacts exist beyond the specified limit, the NextToken element is sent in the response. Use the NextToken value in subsequent requests to retrieve additional contacts. Defaults to None.
        next_token(str, optional): A string token indicating that there might be additional contacts available to be listed. Use the token provided in the Response to use in the subsequent call to ListContacts with the same parameters to retrieve the next page of contacts. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sesv2.contact.init.list_all(ctx, contact_list_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sesv2.contact.init.list_all contact_list_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sesv2",
        operation="list_contacts",
        op_kwargs={
            "ContactListName": contact_list_name,
            "Filter": filter_,
            "PageSize": page_size,
            "NextToken": next_token,
        },
    )


async def update(
    hub,
    ctx,
    contact_list_name: str,
    email_address: str,
    topic_preferences: List = None,
    unsubscribe_all: bool = None,
    attributes_data: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a contact's preferences for a list. It is not necessary to specify all existing topic preferences in the TopicPreferences object, just the ones that need updating.

    Args:
        contact_list_name(str): The name of the contact list.
        email_address(str): The contact's email addres.
        topic_preferences(List, optional): The contact's preference for being opted-in to or opted-out of a topic. Defaults to None.
        unsubscribe_all(bool, optional): A boolean value status noting if the contact is unsubscribed from all contact list topics. Defaults to None.
        attributes_data(str, optional): The attribute data attached to a contact. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sesv2.contact.init.update(
                ctx, contact_list_name=value, email_address=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sesv2.contact.init.update contact_list_name=value, email_address=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sesv2",
        operation="update_contact",
        op_kwargs={
            "ContactListName": contact_list_name,
            "EmailAddress": email_address,
            "TopicPreferences": topic_preferences,
            "UnsubscribeAll": unsubscribe_all,
            "AttributesData": attributes_data,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def cancel(hub, ctx, domain_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Cancels the transfer of a domain from the current AWS account to another AWS account. You initiate a transfer between AWS accounts using TransferDomainToAnotherAwsAccount.   You must cancel the transfer before the other AWS account accepts the transfer using AcceptDomainTransferFromAnotherAwsAccount.  Use either ListOperations or GetOperationDetail to determine whether the operation succeeded. GetOperationDetail provides additional information, for example, Domain Transfer from Aws Account 111122223333 has been cancelled.

    Args:
        domain_name(str): The name of the domain for which you want to cancel the transfer to another AWS account.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53domain.domain.transfer.to_another_aws_account.cancel(
                ctx, domain_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53domain.domain.transfer.to_another_aws_account.cancel domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53domains",
        operation="cancel_domain_transfer_to_another_aws_account",
        op_kwargs={"DomainName": domain_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    client_request_token: str,
    network_id: str,
    node_configuration: Dict,
    member_id: str = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a node on the specified blockchain network. Applies to Hyperledger Fabric and Ethereum.

    Args:
        client_request_token(str): A unique, case-sensitive identifier that you provide to ensure the idempotency of the operation. An idempotent operation completes no more than one time. This identifier is required only if you make a service request directly using an HTTP client. It is generated automatically if you use an AWS SDK or the AWS CLI.
        network_id(str): The unique identifier of the network for the node. Ethereum public networks have the following NetworkIds:    n-ethereum-mainnet     n-ethereum-rinkeby     n-ethereum-ropsten   .
        member_id(str, optional): The unique identifier of the member that owns this node. Applies only to Hyperledger Fabric. Defaults to None.
        node_configuration(Dict): The properties of a node configuration.
        tags(Dict, optional): Tags to assign to the node. Each tag consists of a key and optional value. When specifying tags during creation, you can specify multiple key-value pairs in a single request, with an overall maximum of 50 tags added to each resource. For more information about tags, see Tagging Resources in the Amazon Managed Blockchain Ethereum Developer Guide, or Tagging Resources in the Amazon Managed Blockchain Hyperledger Fabric Developer Guide. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.managedblockchain.node.create(
                ctx, client_request_token=value, network_id=value, node_configuration=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.managedblockchain.node.create client_request_token=value, network_id=value, node_configuration=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="managedblockchain",
        operation="create_node",
        op_kwargs={
            "ClientRequestToken": client_request_token,
            "NetworkId": network_id,
            "MemberId": member_id,
            "NodeConfiguration": node_configuration,
            "Tags": tags,
        },
    )


async def delete(
    hub, ctx, network_id: str, node_id: str, member_id: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a node that your AWS account owns. All data on the node is lost and cannot be recovered. Applies to Hyperledger Fabric and Ethereum.

    Args:
        network_id(str): The unique identifier of the network that the node is on. Ethereum public networks have the following NetworkIds:    n-ethereum-mainnet     n-ethereum-rinkeby     n-ethereum-ropsten   .
        member_id(str, optional): The unique identifier of the member that owns this node. Applies only to Hyperledger Fabric and is required for Hyperledger Fabric. Defaults to None.
        node_id(str): The unique identifier of the node.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.managedblockchain.node.delete(
                ctx, network_id=value, node_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.managedblockchain.node.delete network_id=value, node_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="managedblockchain",
        operation="delete_node",
        op_kwargs={"NetworkId": network_id, "MemberId": member_id, "NodeId": node_id},
    )


async def get(hub, ctx, network_id: str, node_id: str, member_id: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns detailed information about a node. Applies to Hyperledger Fabric and Ethereum.

    Args:
        network_id(str): The unique identifier of the network that the node is on.
        member_id(str, optional): The unique identifier of the member that owns the node. Applies only to Hyperledger Fabric and is required for Hyperledger Fabric. Defaults to None.
        node_id(str): The unique identifier of the node.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.managedblockchain.node.get(ctx, network_id=value, node_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.managedblockchain.node.get network_id=value, node_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="managedblockchain",
        operation="get_node",
        op_kwargs={"NetworkId": network_id, "MemberId": member_id, "NodeId": node_id},
    )


async def list_all(
    hub,
    ctx,
    network_id: str,
    member_id: str = None,
    status: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about the nodes within a network. Applies to Hyperledger Fabric and Ethereum.

    Args:
        network_id(str): The unique identifier of the network for which to list nodes.
        member_id(str, optional): The unique identifier of the member who owns the nodes to list. Applies only to Hyperledger Fabric and is required for Hyperledger Fabric. Defaults to None.
        status(str, optional): An optional status specifier. If provided, only nodes currently in this status are listed. Defaults to None.
        max_results(int, optional): The maximum number of nodes to list. Defaults to None.
        next_token(str, optional): The pagination token that indicates the next set of results to retrieve. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.managedblockchain.node.list_all(ctx, network_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.managedblockchain.node.list_all network_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="managedblockchain",
        operation="list_nodes",
        op_kwargs={
            "NetworkId": network_id,
            "MemberId": member_id,
            "Status": status,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def update(
    hub,
    ctx,
    network_id: str,
    node_id: str,
    member_id: str = None,
    log_publishing_configuration: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a node configuration with new parameters. Applies only to Hyperledger Fabric.

    Args:
        network_id(str): The unique identifier of the network that the node is on.
        member_id(str, optional): The unique identifier of the member that owns the node. Applies only to Hyperledger Fabric. Defaults to None.
        node_id(str): The unique identifier of the node.
        log_publishing_configuration(Dict, optional): Configuration properties for publishing to Amazon CloudWatch Logs. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.managedblockchain.node.update(
                ctx, network_id=value, node_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.managedblockchain.node.update network_id=value, node_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="managedblockchain",
        operation="update_node",
        op_kwargs={
            "NetworkId": network_id,
            "MemberId": member_id,
            "NodeId": node_id,
            "LogPublishingConfiguration": log_publishing_configuration,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def attach(hub, ctx, load_balancer_name: str, subnets: List) -> Dict:
    r"""
    **Autogenerated function**

    Adds one or more subnets to the set of configured subnets for the specified load balancer. The load balancer evenly distributes requests across all registered subnets. For more information, see Add or Remove Subnets for Your Load Balancer in a VPC in the Classic Load Balancers Guide.

    Args:
        load_balancer_name(str): The name of the load balancer.
        subnets(List): The IDs of the subnets to add. You can add only one subnet per Availability Zone.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elb.load_balancer.to_subnet.attach(
                ctx, load_balancer_name=value, subnets=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elb.load_balancer.to_subnet.attach load_balancer_name=value, subnets=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elb",
        operation="attach_load_balancer_to_subnets",
        op_kwargs={"LoadBalancerName": load_balancer_name, "Subnets": subnets},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    dry_run: bool = None,
    filters: List = None,
    import_task_ids: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Displays details about an import virtual machine or import snapshot tasks that are already created.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        filters(List, optional): Filter tasks using the task-state filter and one of the following values: active, completed, deleting, or deleted. Defaults to None.
        import_task_ids(List, optional): The IDs of the import image tasks. Defaults to None.
        max_results(int, optional): The maximum number of results to return in a single call. Defaults to None.
        next_token(str, optional): A token that indicates the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.import_.image_task.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.import_.image_task.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_import_image_tasks",
        op_kwargs={
            "DryRun": dry_run,
            "Filters": filters,
            "ImportTaskIds": import_task_ids,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub, ctx, resource_arn: str, position: str = None, limit: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets the Tags collection for a given resource.

    Args:
        resource_arn(str): [Required] The ARN of a resource that can be tagged.
        position(str, optional): (Not currently supported) The current pagination position in the paged result set. Defaults to None.
        limit(int, optional): (Not currently supported) The maximum number of returned results per page. The default value is 25 and the maximum value is 500. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.tags.get(ctx, resource_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.tags.get resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="get_tags",
        op_kwargs={"resourceArn": resource_arn, "position": position, "limit": limit},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    instance_information_filter_list: List = None,
    filters: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes one or more of your instances, including information about the operating system platform, the version of SSM Agent installed on the instance, instance status, and so on. If you specify one or more instance IDs, it returns information for those instances. If you don't specify instance IDs, it returns information for all your instances. If you specify an instance ID that isn't valid or an instance that you don't own, you receive an error.  The IamRole field for this API operation is the Identity and Access Management (IAM) role assigned to on-premises instances. This call doesn't return the IAM role for EC2 instances.

    Args:
        instance_information_filter_list(List, optional): This is a legacy method. We recommend that you don't use this method. Instead, use the Filters data type. Filters enables you to return instance information by filtering based on tags applied to managed instances.  Attempting to use InstanceInformationFilterList and Filters leads to an exception error.  . Defaults to None.
        filters(List, optional): One or more filters. Use a filter to return a more specific list of instances. You can filter based on tags applied to EC2 instances. Use this Filters data type instead of InstanceInformationFilterList, which is deprecated. Defaults to None.
        max_results(int, optional): The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results. . Defaults to None.
        next_token(str, optional): The token for the next set of items to return. (You received this token from a previous call.). Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.instance.information.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.instance.information.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="describe_instance_information",
        op_kwargs={
            "InstanceInformationFilterList": instance_information_filter_list,
            "Filters": filters,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(
    hub, ctx, bucket: str, id_: str, expected_bucket_owner: str = None
) -> None:
    r"""
    **Autogenerated function**

    Deletes an inventory configuration (identified by the inventory ID) from the bucket. To use this operation, you must have permissions to perform the s3:PutInventoryConfiguration action. The bucket owner has this permission by default. The bucket owner can grant this permission to others. For more information about permissions, see Permissions Related to Bucket Subresource Operations and Managing Access Permissions to Your Amazon S3 Resources. For information about the Amazon S3 inventory feature, see Amazon S3 Inventory. Operations related to DeleteBucketInventoryConfiguration include:     GetBucketInventoryConfiguration     PutBucketInventoryConfiguration     ListBucketInventoryConfigurations

    Args:
        bucket(str): The name of the bucket containing the inventory configuration to delete.
        id_(str): The ID used to identify the inventory configuration.
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.bucket.inventory_configuration.delete(
                ctx, bucket=value, id_=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.bucket.inventory_configuration.delete bucket=value, id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="delete_bucket_inventory_configuration",
        op_kwargs={
            "Bucket": bucket,
            "Id": id_,
            "ExpectedBucketOwner": expected_bucket_owner,
        },
    )


async def get(
    hub, ctx, bucket: str, id_: str, expected_bucket_owner: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns an inventory configuration (identified by the inventory configuration ID) from the bucket. To use this operation, you must have permissions to perform the s3:GetInventoryConfiguration action. The bucket owner has this permission by default and can grant this permission to others. For more information about permissions, see Permissions Related to Bucket Subresource Operations and Managing Access Permissions to Your Amazon S3 Resources. For information about the Amazon S3 inventory feature, see Amazon S3 Inventory. The following operations are related to GetBucketInventoryConfiguration:    DeleteBucketInventoryConfiguration     ListBucketInventoryConfigurations     PutBucketInventoryConfiguration

    Args:
        bucket(str): The name of the bucket containing the inventory configuration to retrieve.
        id_(str): The ID used to identify the inventory configuration.
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.bucket.inventory_configuration.get(
                ctx, bucket=value, id_=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.bucket.inventory_configuration.get bucket=value, id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="get_bucket_inventory_configuration",
        op_kwargs={
            "Bucket": bucket,
            "Id": id_,
            "ExpectedBucketOwner": expected_bucket_owner,
        },
    )


async def list_all(
    hub,
    ctx,
    bucket: str,
    continuation_token: str = None,
    expected_bucket_owner: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of inventory configurations for the bucket. You can have up to 1,000 analytics configurations per bucket. This action supports list pagination and does not return more than 100 configurations at a time. Always check the IsTruncated element in the response. If there are no more configurations to list, IsTruncated is set to false. If there are more configurations to list, IsTruncated is set to true, and there is a value in NextContinuationToken. You use the NextContinuationToken value to continue the pagination of the list by passing the value in continuation-token in the request to GET the next page.  To use this operation, you must have permissions to perform the s3:GetInventoryConfiguration action. The bucket owner has this permission by default. The bucket owner can grant this permission to others. For more information about permissions, see Permissions Related to Bucket Subresource Operations and Managing Access Permissions to Your Amazon S3 Resources. For information about the Amazon S3 inventory feature, see Amazon S3 Inventory  The following operations are related to ListBucketInventoryConfigurations:    GetBucketInventoryConfiguration     DeleteBucketInventoryConfiguration     PutBucketInventoryConfiguration

    Args:
        bucket(str): The name of the bucket containing the inventory configurations to retrieve.
        continuation_token(str, optional): The marker used to continue an inventory configuration listing that has been truncated. Use the NextContinuationToken from a previously truncated list response to continue the listing. The continuation token is an opaque value that Amazon S3 understands. Defaults to None.
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.bucket.inventory_configuration.list_all(ctx, bucket=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.bucket.inventory_configuration.list_all bucket=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="list_bucket_inventory_configurations",
        op_kwargs={
            "Bucket": bucket,
            "ContinuationToken": continuation_token,
            "ExpectedBucketOwner": expected_bucket_owner,
        },
    )


async def put(
    hub,
    ctx,
    bucket: str,
    id_: str,
    inventory_configuration: Dict,
    expected_bucket_owner: str = None,
) -> None:
    r"""
    **Autogenerated function**

    This implementation of the PUT action adds an inventory configuration (identified by the inventory ID) to the bucket. You can have up to 1,000 inventory configurations per bucket.  Amazon S3 inventory generates inventories of the objects in the bucket on a daily or weekly basis, and the results are published to a flat file. The bucket that is inventoried is called the source bucket, and the bucket where the inventory flat file is stored is called the destination bucket. The destination bucket must be in the same AWS Region as the source bucket.  When you configure an inventory for a source bucket, you specify the destination bucket where you want the inventory to be stored, and whether to generate the inventory daily or weekly. You can also configure what object metadata to include and whether to inventory all object versions or only current versions. For more information, see Amazon S3 Inventory in the Amazon S3 User Guide.  You must create a bucket policy on the destination bucket to grant permissions to Amazon S3 to write objects to the bucket in the defined location. For an example policy, see  Granting Permissions for Amazon S3 Inventory and Storage Class Analysis.  To use this operation, you must have permissions to perform the s3:PutInventoryConfiguration action. The bucket owner has this permission by default and can grant this permission to others. For more information about permissions, see Permissions Related to Bucket Subresource Operations and Managing Access Permissions to Your Amazon S3 Resources in the Amazon S3 User Guide.  Special Errors     HTTP 400 Bad Request Error     Code: InvalidArgument    Cause: Invalid Argument      HTTP 400 Bad Request Error     Code: TooManyConfigurations    Cause: You are attempting to create a new configuration but have already reached the 1,000-configuration limit.       HTTP 403 Forbidden Error     Code: AccessDenied    Cause: You are not the owner of the specified bucket, or you do not have the s3:PutInventoryConfiguration bucket permission to set the configuration on the bucket.       Related Resources     GetBucketInventoryConfiguration     DeleteBucketInventoryConfiguration     ListBucketInventoryConfigurations

    Args:
        bucket(str): The name of the bucket where the inventory configuration will be stored.
        id_(str): The ID used to identify the inventory configuration.
        inventory_configuration(Dict): Specifies the inventory configuration.
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.bucket.inventory_configuration.put(
                ctx, bucket=value, id_=value, inventory_configuration=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.bucket.inventory_configuration.put bucket=value, id_=value, inventory_configuration=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="put_bucket_inventory_configuration",
        op_kwargs={
            "Bucket": bucket,
            "Id": id_,
            "InventoryConfiguration": inventory_configuration,
            "ExpectedBucketOwner": expected_bucket_owner,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update(
    hub, ctx, application_id: str, journey_id: str, journey_state_request: Dict
) -> Dict:
    r"""
    **Autogenerated function**

    Cancels (stops) an active journey.

    Args:
        application_id(str): The unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.
        journey_id(str): The unique identifier for the journey.
        journey_state_request(Dict): Changes the status of a journey.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint.journey.state.update(
                ctx, application_id=value, journey_id=value, journey_state_request=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint.journey.state.update application_id=value, journey_id=value, journey_state_request=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint",
        operation="update_journey_state",
        op_kwargs={
            "ApplicationId": application_id,
            "JourneyId": journey_id,
            "JourneyStateRequest": journey_state_request,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get(hub, ctx, events: List, type_: str) -> Dict:
    r"""
    **Autogenerated function**

    Get the discovered schema that was generated based on sampled events.

    Args:
        events(List): An array of strings where each string is a JSON event. These are the events that were used to generate the schema. The array includes a single type of event and has a maximum size of 10 events.
        type_(str): The type of event.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.schemas.discovered_schema.get(ctx, events=value, type_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.schemas.discovered_schema.get events=value, type_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="schemas",
        operation="get_discovered_schema",
        op_kwargs={"Events": events, "Type": type_},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    aws_account_id: str,
    analysis_id: str,
    name: str,
    source_entity: Dict,
    parameters: Dict = None,
    permissions: List = None,
    theme_arn: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an analysis in Amazon QuickSight.

    Args:
        aws_account_id(str): The ID of the Amazon Web Services account; where you are creating an analysis.
        analysis_id(str): The ID for the analysis that you're creating. This ID displays in the URL of the analysis.
        name(str): A descriptive name for the analysis that you're creating. This name displays for the analysis in the QuickSight console. .
        parameters(Dict, optional): The parameter names and override values that you want to use. An analysis can have any parameter type, and some parameters might accept multiple values. . Defaults to None.
        permissions(List, optional): A structure that describes the principals and the resource-level permissions on an analysis. You can use the Permissions structure to grant permissions by providing a list of Identity and Access Management (IAM) action information for each principal listed by Amazon Resource Name (ARN).  To specify no permissions, omit Permissions. Defaults to None.
        source_entity(Dict): A source entity to use for the analysis that you're creating. This metadata structure contains details that describe a source template and one or more datasets.
        theme_arn(str, optional): The ARN for the theme to apply to the analysis that you're creating. To see the theme in the QuickSight console, make sure that you have access to it. Defaults to None.
        tags(List, optional): Contains a map of the key-value pairs for the resource tag or tags assigned to the analysis. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.analysis.init.create(
                ctx, aws_account_id=value, analysis_id=value, name=value, source_entity=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.analysis.init.create aws_account_id=value, analysis_id=value, name=value, source_entity=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="create_analysis",
        op_kwargs={
            "AwsAccountId": aws_account_id,
            "AnalysisId": analysis_id,
            "Name": name,
            "Parameters": parameters,
            "Permissions": permissions,
            "SourceEntity": source_entity,
            "ThemeArn": theme_arn,
            "Tags": tags,
        },
    )


async def delete(
    hub,
    ctx,
    aws_account_id: str,
    analysis_id: str,
    recovery_window_in_days: int = None,
    force_delete_without_recovery: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an analysis from Amazon QuickSight. You can optionally include a recovery window during which you can restore the analysis. If you don't specify a recovery window value, the operation defaults to 30 days. QuickSight attaches a DeletionTime stamp to the response that specifies the end of the recovery window. At the end of the recovery window, QuickSight deletes the analysis permanently. At any time before recovery window ends, you can use the RestoreAnalysis API operation to remove the DeletionTime stamp and cancel the deletion of the analysis. The analysis remains visible in the API until it's deleted, so you can describe it but you can't make a template from it. An analysis that's scheduled for deletion isn't accessible in the QuickSight console. To access it in the console, restore it. Deleting an analysis doesn't delete the dashboards that you publish from it.

    Args:
        aws_account_id(str): The ID of the Amazon Web Services account; where you want to delete an analysis.
        analysis_id(str): The ID of the analysis that you're deleting.
        recovery_window_in_days(int, optional): A value that specifies the number of days that QuickSight waits before it deletes the analysis. You can't use this parameter with the ForceDeleteWithoutRecovery option in the same API call. The default value is 30. Defaults to None.
        force_delete_without_recovery(bool, optional): This option defaults to the value NoForceDeleteWithoutRecovery. To immediately delete the analysis, add the ForceDeleteWithoutRecovery option. You can't restore an analysis after it's deleted. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.analysis.init.delete(
                ctx, aws_account_id=value, analysis_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.analysis.init.delete aws_account_id=value, analysis_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="delete_analysis",
        op_kwargs={
            "AwsAccountId": aws_account_id,
            "AnalysisId": analysis_id,
            "RecoveryWindowInDays": recovery_window_in_days,
            "ForceDeleteWithoutRecovery": force_delete_without_recovery,
        },
    )


async def describe(hub, ctx, aws_account_id: str, analysis_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Provides a summary of the metadata for an analysis.

    Args:
        aws_account_id(str): The ID of the Amazon Web Services account; that contains the analysis. You must be using the Amazon Web Services account; that the analysis is in.
        analysis_id(str): The ID of the analysis that you're describing. The ID is part of the URL of the analysis.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.analysis.init.describe(
                ctx, aws_account_id=value, analysis_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.analysis.init.describe aws_account_id=value, analysis_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="describe_analysis",
        op_kwargs={"AwsAccountId": aws_account_id, "AnalysisId": analysis_id},
    )


async def list_all(
    hub, ctx, aws_account_id: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists Amazon QuickSight analyses that exist in the specified Amazon Web Services account;.

    Args:
        aws_account_id(str): The ID of the Amazon Web Services account; that contains the analyses.
        next_token(str, optional): A pagination token that can be used in a subsequent request. Defaults to None.
        max_results(int, optional): The maximum number of results to return. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.analysis.init.list_all(ctx, aws_account_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.analysis.init.list_all aws_account_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="list_analyses",
        op_kwargs={
            "AwsAccountId": aws_account_id,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def restore(hub, ctx, aws_account_id: str, analysis_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Restores an analysis.

    Args:
        aws_account_id(str): The ID of the Amazon Web Services account; that contains the analysis.
        analysis_id(str): The ID of the analysis that you're restoring.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.analysis.init.restore(
                ctx, aws_account_id=value, analysis_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.analysis.init.restore aws_account_id=value, analysis_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="restore_analysis",
        op_kwargs={"AwsAccountId": aws_account_id, "AnalysisId": analysis_id},
    )


async def search(
    hub,
    ctx,
    aws_account_id: str,
    filters: List,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Searches for analyses that belong to the user specified in the filter.  This operation is eventually consistent. The results are best effort and may not reflect very recent updates and changes.

    Args:
        aws_account_id(str): The ID of the Amazon Web Services account; that contains the analyses that you're searching for.
        filters(List): The structure for the search filters that you want to apply to your search. .
        next_token(str, optional): A pagination token that can be used in a subsequent request. Defaults to None.
        max_results(int, optional): The maximum number of results to return. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.analysis.init.search(
                ctx, aws_account_id=value, filters=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.analysis.init.search aws_account_id=value, filters=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="search_analyses",
        op_kwargs={
            "AwsAccountId": aws_account_id,
            "Filters": filters,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def update(
    hub,
    ctx,
    aws_account_id: str,
    analysis_id: str,
    name: str,
    source_entity: Dict,
    parameters: Dict = None,
    theme_arn: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an analysis in Amazon QuickSight

    Args:
        aws_account_id(str): The ID of the Amazon Web Services account; that contains the analysis that you're updating.
        analysis_id(str): The ID for the analysis that you're updating. This ID displays in the URL of the analysis.
        name(str): A descriptive name for the analysis that you're updating. This name displays for the analysis in the QuickSight console.
        parameters(Dict, optional): The parameter names and override values that you want to use. An analysis can have any parameter type, and some parameters might accept multiple values. . Defaults to None.
        source_entity(Dict): A source entity to use for the analysis that you're updating. This metadata structure contains details that describe a source template and one or more datasets.
        theme_arn(str, optional): The Amazon Resource Name (ARN) for the theme to apply to the analysis that you're creating. To see the theme in the QuickSight console, make sure that you have access to it. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.analysis.init.update(
                ctx, aws_account_id=value, analysis_id=value, name=value, source_entity=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.analysis.init.update aws_account_id=value, analysis_id=value, name=value, source_entity=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="update_analysis",
        op_kwargs={
            "AwsAccountId": aws_account_id,
            "AnalysisId": analysis_id,
            "Name": name,
            "Parameters": parameters,
            "SourceEntity": source_entity,
            "ThemeArn": theme_arn,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    subnet_id: str,
    cidr: str,
    reservation_type: str,
    tag_specifications: List = None,
    description: str = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a subnet CIDR reservation. For information about subnet CIDR reservations, see Subnet CIDR reservations in the Amazon Virtual Private Cloud User Guide.

    Args:
        tag_specifications(List, optional): The tags to assign to the subnet CIDR reservation. Defaults to None.
        subnet_id(str): The ID of the subnet.
        cidr(str): The IPv4 or IPV6 CIDR range to reserve.
        reservation_type(str): The type of reservation. The following are valid values:    prefix: The Amazon EC2 Prefix Delegation feature assigns the IP addresses to network interfaces that are associated with an instance. For information about Prefix Delegation, see Prefix Delegation for Amazon EC2 network interfaces in the Amazon Elastic Compute Cloud User Guide.    explicit: You manually assign the IP addresses to resources that reside in your subnet.   .
        description(str, optional): The description to assign to the subnet CIDR reservation. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.subnet.cidr.reservation.create(
                ctx, subnet_id=value, cidr=value, reservation_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.subnet.cidr.reservation.create subnet_id=value, cidr=value, reservation_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="create_subnet_cidr_reservation",
        op_kwargs={
            "TagSpecifications": tag_specifications,
            "SubnetId": subnet_id,
            "Cidr": cidr,
            "ReservationType": reservation_type,
            "Description": description,
            "DryRun": dry_run,
        },
    )


async def delete(
    hub, ctx, subnet_cidr_reservation_id: str, dry_run: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a subnet CIDR reservation.

    Args:
        subnet_cidr_reservation_id(str): The ID of the subnet CIDR reservation.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.subnet.cidr.reservation.delete(
                ctx, subnet_cidr_reservation_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.subnet.cidr.reservation.delete subnet_cidr_reservation_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="delete_subnet_cidr_reservation",
        op_kwargs={
            "SubnetCidrReservationId": subnet_cidr_reservation_id,
            "DryRun": dry_run,
        },
    )


async def get_all(
    hub,
    ctx,
    subnet_id: str,
    filters: List = None,
    dry_run: bool = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about the subnet CIDR reservations.

    Args:
        filters(List, optional): One or more filters.    reservationType - The type of reservation (prefix | explicit).    subnet-id - The ID of the subnet.    tag:<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.  . Defaults to None.
        subnet_id(str): The ID of the subnet.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        next_token(str, optional): The token for the next page of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.subnet.cidr.reservation.get_all(ctx, subnet_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.subnet.cidr.reservation.get_all subnet_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="get_subnet_cidr_reservations",
        op_kwargs={
            "Filters": filters,
            "SubnetId": subnet_id,
            "DryRun": dry_run,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(hub, ctx, include_inactive: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns the bundles that you can apply to a Amazon Lightsail bucket. The bucket bundle specifies the monthly cost, storage quota, and data transfer quota for a bucket. Use the UpdateBucketBundle action to update the bundle for a bucket.

    Args:
        include_inactive(bool, optional): A Boolean value that indicates whether to include inactive (unavailable) bundles in the response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.bucket.bundle.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.bucket.bundle.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="get_bucket_bundles",
        op_kwargs={"includeInactive": include_inactive},
    )


async def update(hub, ctx, bucket_name: str, bundle_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Updates the bundle, or storage plan, of an existing Amazon Lightsail bucket. A bucket bundle specifies the monthly cost, storage space, and data transfer quota for a bucket. You can update a bucket's bundle only one time within a monthly AWS billing cycle. To determine if you can update a bucket's bundle, use the GetBuckets action. The ableToUpdateBundle parameter in the response will indicate whether you can currently update a bucket's bundle. Update a bucket's bundle if it's consistently going over its storage space or data transfer quota, or if a bucket's usage is consistently in the lower range of its storage space or data transfer quota. Due to the unpredictable usage fluctuations that a bucket might experience, we strongly recommend that you update a bucket's bundle only as a long-term strategy, instead of as a short-term, monthly cost-cutting measure. Choose a bucket bundle that will provide the bucket with ample storage space and data transfer for a long time to come.

    Args:
        bucket_name(str): The name of the bucket for which to update the bundle.
        bundle_id(str): The ID of the new bundle to apply to the bucket. Use the GetBucketBundles action to get a list of bundle IDs that you can specify.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.bucket.bundle.update(
                ctx, bucket_name=value, bundle_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.bucket.bundle.update bucket_name=value, bundle_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="update_bucket_bundle",
        op_kwargs={"bucketName": bucket_name, "bundleId": bundle_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def start(hub, ctx, client_id: str, client_secret: str, start_url: str) -> Dict:
    r"""
    **Autogenerated function**

    Initiates device authorization by requesting a pair of verification codes from the authorization service.

    Args:
        client_id(str): The unique identifier string for the client that is registered with AWS SSO. This value should come from the persisted result of the RegisterClient API operation.
        client_secret(str): A secret string that is generated for the client. This value should come from the persisted result of the RegisterClient API operation.
        start_url(str): The URL for the AWS SSO user portal. For more information, see Using the User Portal in the AWS Single Sign-On User Guide.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sso_oidc.device_authorization.start(
                ctx, client_id=value, client_secret=value, start_url=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sso_oidc.device_authorization.start client_id=value, client_secret=value, start_url=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sso-oidc",
        operation="start_device_authorization",
        op_kwargs={
            "clientId": client_id,
            "clientSecret": client_secret,
            "startUrl": start_url,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe(
    hub,
    ctx,
    filters: List = None,
    max_results: int = None,
    next_token: str = None,
    volume_ids: List = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the status of the specified volumes. Volume status provides the result of the checks performed on your volumes to determine events that can impair the performance of your volumes. The performance of a volume can be affected if an issue occurs on the volume's underlying host. If the volume's underlying host experiences a power outage or system issue, after the system is restored, there could be data inconsistencies on the volume. Volume events notify you if this occurs. Volume actions notify you if any action needs to be taken in response to the event. The DescribeVolumeStatus operation provides the following information about the specified volumes:  Status: Reflects the current status of the volume. The possible values are ok, impaired , warning, or insufficient-data. If all checks pass, the overall status of the volume is ok. If the check fails, the overall status is impaired. If the status is insufficient-data, then the checks might still be taking place on your volume at the time. We recommend that you retry the request. For more information about volume status, see Monitor the status of your volumes in the Amazon Elastic Compute Cloud User Guide.  Events: Reflect the cause of a volume status and might require you to take action. For example, if your volume returns an impaired status, then the volume event might be potential-data-inconsistency. This means that your volume has been affected by an issue with the underlying host, has all I/O operations disabled, and might have inconsistent data.  Actions: Reflect the actions you might have to take in response to an event. For example, if the status of the volume is impaired and the volume event shows potential-data-inconsistency, then the action shows enable-volume-io. This means that you may want to enable the I/O operations for the volume by calling the EnableVolumeIO action and then check the volume for data consistency. Volume status is based on the volume status checks, and does not reflect the volume state. Therefore, volume status does not indicate volumes in the error state (for example, when a volume is incapable of accepting I/O.)

    Args:
        filters(List, optional): The filters.    action.code - The action code for the event (for example, enable-volume-io).    action.description - A description of the action.    action.event-id - The event ID associated with the action.    availability-zone - The Availability Zone of the instance.    event.description - A description of the event.    event.event-id - The event ID.    event.event-type - The event type (for io-enabled: passed | failed; for io-performance: io-performance:degraded | io-performance:severely-degraded | io-performance:stalled).    event.not-after - The latest end time for the event.    event.not-before - The earliest start time for the event.    volume-status.details-name - The cause for volume-status.status (io-enabled | io-performance).    volume-status.details-status - The status of volume-status.details-name (for io-enabled: passed | failed; for io-performance: normal | degraded | severely-degraded | stalled).    volume-status.status - The status of the volume (ok | impaired | warning | insufficient-data).  . Defaults to None.
        max_results(int, optional): The maximum number of volume results returned by DescribeVolumeStatus in paginated output. When this parameter is used, the request only returns MaxResults results in a single page along with a NextToken response element. The remaining results of the initial request can be seen by sending another request with the returned NextToken value. This value can be between 5 and 1,000; if MaxResults is given a value larger than 1,000, only 1,000 results are returned. If this parameter is not used, then DescribeVolumeStatus returns all results. You cannot specify this parameter and the volume IDs parameter in the same request. Defaults to None.
        next_token(str, optional): The NextToken value to include in a future DescribeVolumeStatus request. When the results of the request exceed MaxResults, this value can be used to retrieve the next page of results. This value is null when there are no more results to return. Defaults to None.
        volume_ids(List, optional): The IDs of the volumes. Default: Describes all your volumes. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.volume.status.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.volume.status.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_volume_status",
        op_kwargs={
            "Filters": filters,
            "MaxResults": max_results,
            "NextToken": next_token,
            "VolumeIds": volume_ids,
            "DryRun": dry_run,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def deregister(hub, ctx, rds_db_instance_arn: str) -> None:
    r"""
    **Autogenerated function**

    Deregisters an Amazon RDS instance.  Required Permissions: To use this action, an IAM user must have a Manage permissions level for the stack, or an attached policy that explicitly grants permissions. For more information on user permissions, see Managing User Permissions.

    Args:
        rds_db_instance_arn(str): The Amazon RDS instance's ARN.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.rds_db_instance.deregister(
                ctx, rds_db_instance_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.rds_db_instance.deregister rds_db_instance_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="deregister_rds_db_instance",
        op_kwargs={"RdsDbInstanceArn": rds_db_instance_arn},
    )


async def describe_all(
    hub, ctx, stack_id: str, rds_db_instance_arns: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Describes Amazon RDS instances.  Required Permissions: To use this action, an IAM user must have a Show, Deploy, or Manage permissions level for the stack, or an attached policy that explicitly grants permissions. For more information about user permissions, see Managing User Permissions. This call accepts only one resource-identifying parameter.

    Args:
        stack_id(str): The ID of the stack with which the instances are registered. The operation returns descriptions of all registered Amazon RDS instances.
        rds_db_instance_arns(List, optional): An array containing the ARNs of the instances to be described. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.rds_db_instance.describe_all(ctx, stack_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.rds_db_instance.describe_all stack_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="describe_rds_db_instances",
        op_kwargs={"StackId": stack_id, "RdsDbInstanceArns": rds_db_instance_arns},
    )


async def register(
    hub, ctx, stack_id: str, rds_db_instance_arn: str, db_user: str, db_password: str
) -> None:
    r"""
    **Autogenerated function**

    Registers an Amazon RDS instance with a stack.  Required Permissions: To use this action, an IAM user must have a Manage permissions level for the stack, or an attached policy that explicitly grants permissions. For more information on user permissions, see Managing User Permissions.

    Args:
        stack_id(str): The stack ID.
        rds_db_instance_arn(str): The Amazon RDS instance's ARN.
        db_user(str): The database's master user name.
        db_password(str): The database password.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.rds_db_instance.register(
                ctx, stack_id=value, rds_db_instance_arn=value, db_user=value, db_password=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.rds_db_instance.register stack_id=value, rds_db_instance_arn=value, db_user=value, db_password=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="register_rds_db_instance",
        op_kwargs={
            "StackId": stack_id,
            "RdsDbInstanceArn": rds_db_instance_arn,
            "DbUser": db_user,
            "DbPassword": db_password,
        },
    )


async def update(
    hub, ctx, rds_db_instance_arn: str, db_user: str = None, db_password: str = None
) -> None:
    r"""
    **Autogenerated function**

    Updates an Amazon RDS instance.  Required Permissions: To use this action, an IAM user must have a Manage permissions level for the stack, or an attached policy that explicitly grants permissions. For more information on user permissions, see Managing User Permissions.

    Args:
        rds_db_instance_arn(str): The Amazon RDS instance's ARN.
        db_user(str, optional): The master user name. Defaults to None.
        db_password(str, optional): The database password. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.rds_db_instance.update(ctx, rds_db_instance_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.rds_db_instance.update rds_db_instance_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="update_rds_db_instance",
        op_kwargs={
            "RdsDbInstanceArn": rds_db_instance_arn,
            "DbUser": db_user,
            "DbPassword": db_password,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    description: str,
    source: str,
    title: str,
    ops_item_type: str = None,
    operational_data: Dict = None,
    notifications: List = None,
    priority: int = None,
    related_ops_items: List = None,
    tags: List = None,
    category: str = None,
    severity: str = None,
    actual_start_time: str = None,
    actual_end_time: str = None,
    planned_start_time: str = None,
    planned_end_time: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new OpsItem. You must have permission in Identity and Access Management (IAM) to create a new OpsItem. For more information, see Getting started with OpsCenter in the Amazon Web Services Systems Manager User Guide. Operations engineers and IT professionals use Amazon Web Services Systems Manager OpsCenter to view, investigate, and remediate operational issues impacting the performance and health of their Amazon Web Services resources. For more information, see Amazon Web Services Systems Manager OpsCenter in the Amazon Web Services Systems Manager User Guide.

    Args:
        description(str): Information about the OpsItem. .
        ops_item_type(str, optional): The type of OpsItem to create. Currently, the only valid values are /aws/changerequest and /aws/issue. Defaults to None.
        operational_data(Dict, optional): Operational data is custom data that provides useful reference details about the OpsItem. For example, you can specify log files, error strings, license keys, troubleshooting tips, or other relevant data. You enter operational data as key-value pairs. The key has a maximum length of 128 characters. The value has a maximum size of 20 KB.  Operational data keys can't begin with the following: amazon, aws, amzn, ssm, /amazon, /aws, /amzn, /ssm.  You can choose to make the data searchable by other users in the account or you can restrict search access. Searchable data means that all users with access to the OpsItem Overview page (as provided by the DescribeOpsItems API operation) can view and search on the specified data. Operational data that isn't searchable is only viewable by users who have access to the OpsItem (as provided by the GetOpsItem API operation). Use the /aws/resources key in OperationalData to specify a related resource in the request. Use the /aws/automations key in OperationalData to associate an Automation runbook with the OpsItem. To view Amazon Web Services CLI example commands that use these keys, see Creating OpsItems manually in the Amazon Web Services Systems Manager User Guide. Defaults to None.
        notifications(List, optional): The Amazon Resource Name (ARN) of an SNS topic where notifications are sent when this OpsItem is edited or changed. Defaults to None.
        priority(int, optional): The importance of this OpsItem in relation to other OpsItems in the system. Defaults to None.
        related_ops_items(List, optional): One or more OpsItems that share something in common with the current OpsItems. For example, related OpsItems can include OpsItems with similar error messages, impacted resources, or statuses for the impacted resource. Defaults to None.
        source(str): The origin of the OpsItem, such as Amazon EC2 or Systems Manager.  The source name can't contain the following strings: aws, amazon, and amzn.  .
        title(str): A short heading that describes the nature of the OpsItem and the impacted resource.
        tags(List, optional): Optional metadata that you assign to a resource. You can restrict access to OpsItems by using an inline IAM policy that specifies tags. For more information, see Getting started with OpsCenter in the Amazon Web Services Systems Manager User Guide. Tags use a key-value pair. For example:  Key=Department,Value=Finance   To add tags to a new OpsItem, a user must have IAM permissions for both the ssm:CreateOpsItems operation and the ssm:AddTagsToResource operation. To add tags to an existing OpsItem, use the AddTagsToResource operation. . Defaults to None.
        category(str, optional): Specify a category to assign to an OpsItem. . Defaults to None.
        severity(str, optional): Specify a severity to assign to an OpsItem. Defaults to None.
        actual_start_time(str, optional): The time a runbook workflow started. Currently reported only for the OpsItem type /aws/changerequest. Defaults to None.
        actual_end_time(str, optional): The time a runbook workflow ended. Currently reported only for the OpsItem type /aws/changerequest. Defaults to None.
        planned_start_time(str, optional): The time specified in a change request for a runbook workflow to start. Currently supported only for the OpsItem type /aws/changerequest. Defaults to None.
        planned_end_time(str, optional): The time specified in a change request for a runbook workflow to end. Currently supported only for the OpsItem type /aws/changerequest. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.ops.item.init.create(
                ctx, description=value, source=value, title=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.ops.item.init.create description=value, source=value, title=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="create_ops_item",
        op_kwargs={
            "Description": description,
            "OpsItemType": ops_item_type,
            "OperationalData": operational_data,
            "Notifications": notifications,
            "Priority": priority,
            "RelatedOpsItems": related_ops_items,
            "Source": source,
            "Title": title,
            "Tags": tags,
            "Category": category,
            "Severity": severity,
            "ActualStartTime": actual_start_time,
            "ActualEndTime": actual_end_time,
            "PlannedStartTime": planned_start_time,
            "PlannedEndTime": planned_end_time,
        },
    )


async def describe_all(
    hub,
    ctx,
    ops_item_filters: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Query a set of OpsItems. You must have permission in Identity and Access Management (IAM) to query a list of OpsItems. For more information, see Getting started with OpsCenter in the Amazon Web Services Systems Manager User Guide. Operations engineers and IT professionals use Amazon Web Services Systems Manager OpsCenter to view, investigate, and remediate operational issues impacting the performance and health of their Amazon Web Services resources. For more information, see OpsCenter in the Amazon Web Services Systems Manager User Guide.

    Args:
        ops_item_filters(List, optional): One or more filters to limit the response.   Key: CreatedTime Operations: GreaterThan, LessThan   Key: LastModifiedBy Operations: Contains, Equals   Key: LastModifiedTime Operations: GreaterThan, LessThan   Key: Priority Operations: Equals   Key: Source Operations: Contains, Equals   Key: Status Operations: Equals   Key: Title* Operations: Equals,Contains   Key: OperationalData** Operations: Equals   Key: OperationalDataKey Operations: Equals   Key: OperationalDataValue Operations: Equals, Contains   Key: OpsItemId Operations: Equals   Key: ResourceId Operations: Contains   Key: AutomationId Operations: Equals   *The Equals operator for Title matches the first 100 characters. If you specify more than 100 characters, they system returns an error that the filter value exceeds the length limit. **If you filter the response by using the OperationalData operator, specify a key-value pair by using the following JSON format: {"key":"key_name","value":"a_value"}. Defaults to None.
        max_results(int, optional): The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results. Defaults to None.
        next_token(str, optional): A token to start the list. Use this token to get the next set of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.ops.item.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.ops.item.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="describe_ops_items",
        op_kwargs={
            "OpsItemFilters": ops_item_filters,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def get(hub, ctx, ops_item_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Get information about an OpsItem by using the ID. You must have permission in Identity and Access Management (IAM) to view information about an OpsItem. For more information, see Getting started with OpsCenter in the Amazon Web Services Systems Manager User Guide. Operations engineers and IT professionals use Amazon Web Services Systems Manager OpsCenter to view, investigate, and remediate operational issues impacting the performance and health of their Amazon Web Services resources. For more information, see OpsCenter in the Amazon Web Services Systems Manager User Guide.

    Args:
        ops_item_id(str): The ID of the OpsItem that you want to get.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.ops.item.init.get(ctx, ops_item_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.ops.item.init.get ops_item_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="get_ops_item",
        op_kwargs={"OpsItemId": ops_item_id},
    )


async def update(
    hub,
    ctx,
    ops_item_id: str,
    description: str = None,
    operational_data: Dict = None,
    operational_data_to_delete: List = None,
    notifications: List = None,
    priority: int = None,
    related_ops_items: List = None,
    status: str = None,
    title: str = None,
    category: str = None,
    severity: str = None,
    actual_start_time: str = None,
    actual_end_time: str = None,
    planned_start_time: str = None,
    planned_end_time: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Edit or change an OpsItem. You must have permission in Identity and Access Management (IAM) to update an OpsItem. For more information, see Getting started with OpsCenter in the Amazon Web Services Systems Manager User Guide. Operations engineers and IT professionals use Amazon Web Services Systems Manager OpsCenter to view, investigate, and remediate operational issues impacting the performance and health of their Amazon Web Services resources. For more information, see OpsCenter in the Amazon Web Services Systems Manager User Guide.

    Args:
        description(str, optional): Update the information about the OpsItem. Provide enough information so that users reading this OpsItem for the first time understand the issue. . Defaults to None.
        operational_data(Dict, optional): Add new keys or edit existing key-value pairs of the OperationalData map in the OpsItem object. Operational data is custom data that provides useful reference details about the OpsItem. For example, you can specify log files, error strings, license keys, troubleshooting tips, or other relevant data. You enter operational data as key-value pairs. The key has a maximum length of 128 characters. The value has a maximum size of 20 KB.  Operational data keys can't begin with the following: amazon, aws, amzn, ssm, /amazon, /aws, /amzn, /ssm.  You can choose to make the data searchable by other users in the account or you can restrict search access. Searchable data means that all users with access to the OpsItem Overview page (as provided by the DescribeOpsItems API operation) can view and search on the specified data. Operational data that isn't searchable is only viewable by users who have access to the OpsItem (as provided by the GetOpsItem API operation). Use the /aws/resources key in OperationalData to specify a related resource in the request. Use the /aws/automations key in OperationalData to associate an Automation runbook with the OpsItem. To view Amazon Web Services CLI example commands that use these keys, see Creating OpsItems manually in the Amazon Web Services Systems Manager User Guide. Defaults to None.
        operational_data_to_delete(List, optional): Keys that you want to remove from the OperationalData map. Defaults to None.
        notifications(List, optional): The Amazon Resource Name (ARN) of an SNS topic where notifications are sent when this OpsItem is edited or changed. Defaults to None.
        priority(int, optional): The importance of this OpsItem in relation to other OpsItems in the system. Defaults to None.
        related_ops_items(List, optional): One or more OpsItems that share something in common with the current OpsItems. For example, related OpsItems can include OpsItems with similar error messages, impacted resources, or statuses for the impacted resource. Defaults to None.
        status(str, optional): The OpsItem status. Status can be Open, In Progress, or Resolved. For more information, see Editing OpsItem details in the Amazon Web Services Systems Manager User Guide. Defaults to None.
        ops_item_id(str): The ID of the OpsItem.
        title(str, optional): A short heading that describes the nature of the OpsItem and the impacted resource. Defaults to None.
        category(str, optional): Specify a new category for an OpsItem. Defaults to None.
        severity(str, optional): Specify a new severity for an OpsItem. Defaults to None.
        actual_start_time(str, optional): The time a runbook workflow started. Currently reported only for the OpsItem type /aws/changerequest. Defaults to None.
        actual_end_time(str, optional): The time a runbook workflow ended. Currently reported only for the OpsItem type /aws/changerequest. Defaults to None.
        planned_start_time(str, optional): The time specified in a change request for a runbook workflow to start. Currently supported only for the OpsItem type /aws/changerequest. Defaults to None.
        planned_end_time(str, optional): The time specified in a change request for a runbook workflow to end. Currently supported only for the OpsItem type /aws/changerequest. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.ops.item.init.update(ctx, ops_item_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.ops.item.init.update ops_item_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="update_ops_item",
        op_kwargs={
            "Description": description,
            "OperationalData": operational_data,
            "OperationalDataToDelete": operational_data_to_delete,
            "Notifications": notifications,
            "Priority": priority,
            "RelatedOpsItems": related_ops_items,
            "Status": status,
            "OpsItemId": ops_item_id,
            "Title": title,
            "Category": category,
            "Severity": severity,
            "ActualStartTime": actual_start_time,
            "ActualEndTime": actual_end_time,
            "PlannedStartTime": planned_start_time,
            "PlannedEndTime": planned_end_time,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get_all(hub, ctx, repository_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about triggers configured for a repository.

    Args:
        repository_name(str): The name of the repository for which the trigger is configured.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codecommit.repository.trigger.get_all(
                ctx, repository_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codecommit.repository.trigger.get_all repository_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codecommit",
        operation="get_repository_triggers",
        op_kwargs={"repositoryName": repository_name},
    )


async def put_multiple(hub, ctx, repository_name: str, triggers: List) -> Dict:
    r"""
    **Autogenerated function**

    Replaces all triggers for a repository. Used to create or delete triggers.

    Args:
        repository_name(str): The name of the repository where you want to create or update the trigger.
        triggers(List): The JSON block of configuration information for each trigger.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codecommit.repository.trigger.put_multiple(
                ctx, repository_name=value, triggers=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codecommit.repository.trigger.put_multiple repository_name=value, triggers=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codecommit",
        operation="put_repository_triggers",
        op_kwargs={"repositoryName": repository_name, "triggers": triggers},
    )


async def test(hub, ctx, repository_name: str, triggers: List) -> Dict:
    r"""
    **Autogenerated function**

    Tests the functionality of repository triggers by sending information to the trigger target. If real data is available in the repository, the test sends data from the last commit. If no data is available, sample data is generated.

    Args:
        repository_name(str): The name of the repository in which to test the triggers.
        triggers(List): The list of triggers to test.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codecommit.repository.trigger.test(
                ctx, repository_name=value, triggers=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codecommit.repository.trigger.test repository_name=value, triggers=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codecommit",
        operation="test_repository_triggers",
        op_kwargs={"repositoryName": repository_name, "triggers": triggers},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(hub, ctx, label: str) -> Dict:
    r"""
    **Autogenerated function**

    This is documentation for AWS CloudHSM Classic. For more information, see AWS CloudHSM Classic FAQs, the AWS CloudHSM Classic User Guide, and the AWS CloudHSM Classic API Reference.  For information about the current version of AWS CloudHSM, see AWS CloudHSM, the AWS CloudHSM User Guide, and the AWS CloudHSM API Reference. Creates a high-availability partition group. A high-availability partition group is a group of partitions that spans multiple physical HSMs.

    Args:
        label(str): The label of the new high-availability partition group.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudhsm.hapg.create(ctx, label=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudhsm.hapg.create label=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudhsm",
        operation="create_hapg",
        op_kwargs={"Label": label},
    )


async def delete(hub, ctx, hapg_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    This is documentation for AWS CloudHSM Classic. For more information, see AWS CloudHSM Classic FAQs, the AWS CloudHSM Classic User Guide, and the AWS CloudHSM Classic API Reference.  For information about the current version of AWS CloudHSM, see AWS CloudHSM, the AWS CloudHSM User Guide, and the AWS CloudHSM API Reference. Deletes a high-availability partition group.

    Args:
        hapg_arn(str): The ARN of the high-availability partition group to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudhsm.hapg.delete(ctx, hapg_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudhsm.hapg.delete hapg_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudhsm",
        operation="delete_hapg",
        op_kwargs={"HapgArn": hapg_arn},
    )


async def describe(hub, ctx, hapg_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    This is documentation for AWS CloudHSM Classic. For more information, see AWS CloudHSM Classic FAQs, the AWS CloudHSM Classic User Guide, and the AWS CloudHSM Classic API Reference.  For information about the current version of AWS CloudHSM, see AWS CloudHSM, the AWS CloudHSM User Guide, and the AWS CloudHSM API Reference. Retrieves information about a high-availability partition group.

    Args:
        hapg_arn(str): The ARN of the high-availability partition group to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudhsm.hapg.describe(ctx, hapg_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudhsm.hapg.describe hapg_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudhsm",
        operation="describe_hapg",
        op_kwargs={"HapgArn": hapg_arn},
    )


async def list_all(hub, ctx, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    This is documentation for AWS CloudHSM Classic. For more information, see AWS CloudHSM Classic FAQs, the AWS CloudHSM Classic User Guide, and the AWS CloudHSM Classic API Reference.  For information about the current version of AWS CloudHSM, see AWS CloudHSM, the AWS CloudHSM User Guide, and the AWS CloudHSM API Reference. Lists the high-availability partition groups for the account. This operation supports pagination with the use of the NextToken member. If more results are available, the NextToken member of the response contains a token that you pass in the next call to ListHapgs to retrieve the next set of items.

    Args:
        next_token(str, optional): The NextToken value from a previous call to ListHapgs. Pass null if this is the first call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudhsm.hapg.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudhsm.hapg.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudhsm",
        operation="list_hapgs",
        op_kwargs={"NextToken": next_token},
    )


async def modify(
    hub, ctx, hapg_arn: str, label: str = None, partition_serial_list: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    This is documentation for AWS CloudHSM Classic. For more information, see AWS CloudHSM Classic FAQs, the AWS CloudHSM Classic User Guide, and the AWS CloudHSM Classic API Reference.  For information about the current version of AWS CloudHSM, see AWS CloudHSM, the AWS CloudHSM User Guide, and the AWS CloudHSM API Reference. Modifies an existing high-availability partition group.

    Args:
        hapg_arn(str): The ARN of the high-availability partition group to modify.
        label(str, optional): The new label for the high-availability partition group. Defaults to None.
        partition_serial_list(List, optional): The list of partition serial numbers to make members of the high-availability partition group. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudhsm.hapg.modify(ctx, hapg_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudhsm.hapg.modify hapg_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudhsm",
        operation="modify_hapg",
        op_kwargs={
            "HapgArn": hapg_arn,
            "Label": label,
            "PartitionSerialList": partition_serial_list,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, availability_zone: str, dry_run: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Creates a default subnet with a size /20 IPv4 CIDR block in the specified Availability Zone in your default VPC. You can have only one default subnet per Availability Zone. For more information, see Creating a default subnet in the Amazon Virtual Private Cloud User Guide.

    Args:
        availability_zone(str): The Availability Zone in which to create the default subnet.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.default.subnet.create(ctx, availability_zone=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.default.subnet.create availability_zone=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="create_default_subnet",
        op_kwargs={"AvailabilityZone": availability_zone, "DryRun": dry_run},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(hub, ctx, cluster_id: str, marker: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Provides information about the bootstrap actions associated with a cluster.

    Args:
        cluster_id(str): The cluster identifier for the bootstrap actions to list.
        marker(str, optional): The pagination token that indicates the next set of results to retrieve. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.emr.bootstrap_action.list_all(ctx, cluster_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.emr.bootstrap_action.list_all cluster_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="emr",
        operation="list_bootstrap_actions",
        op_kwargs={"ClusterId": cluster_id, "Marker": marker},
    )
